==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/General/lyrics/translations/lyrics_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="35"/>
        <source>View Lyrics</source>
        <translation>歌詞を表示</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="36"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="29"/>
        <source>Lyrics Plugin</source>
        <translation>歌詞プラグイン</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="50"/>
        <source>About Lyrics Plugin</source>
        <translation>歌詞プラグインについて</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>QMMP 歌詞プラグイン</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>This plugin retrieves lyrics from lyricsplugin.com</source>
        <translation>このプラグインは lyricsplugin.com より歌詞を取得します</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>歌詞プラグイン</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="31"/>
        <source>Artist:</source>
        <translation>アーティスト:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="41"/>
        <source>Title:</source>
        <translation>タイトル:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="51"/>
        <source>Search</source>
        <translation>検索</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="60"/>
        <source>No connection</source>
        <translation>接続できません</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="64"/>
        <source>Done</source>
        <translation>完了</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="67"/>
        <source>Error</source>
        <translation>事故</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="115"/>
        <source>Not found</source>
        <translation>見付かりません</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="96"/>
        <location filename="../lyricswindow.cpp" line="126"/>
        <source>Receiving</source>
        <translation>取得中</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="127"/>
        <source>Lyrics: %1 - %2</source>
        <translation>%1 - %2 の歌詞</translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/General/lyrics/translations/lyrics_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="33"/>
        <source>View Lyrics</source>
        <translation>歌詞を表示</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="34"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="30"/>
        <source>Lyrics Plugin</source>
        <translation>歌詞プラグイン</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>About Lyrics Plugin</source>
        <translation>歌詞プラグインについて</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>QMMP 歌詞プラグイン</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>This plugin retrieves lyrics from LyricWiki</source>
        <translation>このプラグインは LyricWiki より歌詞を取得します</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>歌詞プラグイン</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="31"/>
        <source>Artist:</source>
        <translation>アーティスト:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="41"/>
        <source>Title:</source>
        <translation>タイトル:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="51"/>
        <source>Search</source>
        <translation>検索</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="60"/>
        <source>No connection</source>
        <translation>接続できません</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="64"/>
        <source>Done</source>
        <translation>完了</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="67"/>
        <location filename="../lyricswindow.cpp" line="91"/>
        <location filename="../lyricswindow.cpp" line="97"/>
        <location filename="../lyricswindow.cpp" line="105"/>
        <location filename="../lyricswindow.cpp" line="113"/>
        <location filename="../lyricswindow.cpp" line="124"/>
        <source>Error</source>
        <translation>事故</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="118"/>
        <location filename="../lyricswindow.cpp" line="153"/>
        <source>Not found</source>
        <translation>見付かりません</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="139"/>
        <location filename="../lyricswindow.cpp" line="164"/>
        <source>Receiving</source>
        <translation>取得中</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="165"/>
        <source>Lyrics: %1 - %2</source>
        <translation>%1 - %2 の歌詞</translation>
    </message>
</context>
</TS>
